summaryrefslogtreecommitdiff
path: root/oox
diff options
context:
space:
mode:
authorBalazs Varga <balazs.varga.extern@allotropia.de>2022-08-08 18:56:04 +0200
committerBalazs Varga <balazs.varga.extern@allotropia.de>2022-08-09 11:35:42 +0200
commit071a36e042c76286fedb38f479dac79f29b661f9 (patch)
tree870d32a748337201581940ed2514be5bca9d9b31 /oox
parenta28ff6a920492b64095b30cf7800b0678ea84c60 (diff)
tdf#150176 pptx chart import: fix automatic border style
Do not set the default border style for chart area in case of pptx charts, if it is came from the MSO as an automtic line style. regression from commit: 0dac43445b35da7e554dd4d7574c59611a0d0be1 (tdf#81437 XLSX import: fix missing chart border) Change-Id: Iaaaecc1dffe80c3f1528851e707236f2f7228bee Reviewed-on: https://gerrit.libreoffice.org/c/core/+/137993 Tested-by: Jenkins Reviewed-by: Balazs Varga <balazs.varga.extern@allotropia.de>
Diffstat (limited to 'oox')
-rw-r--r--oox/source/drawingml/chart/objectformatter.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/oox/source/drawingml/chart/objectformatter.cxx b/oox/source/drawingml/chart/objectformatter.cxx
index 14c96d166a03..5644b9eedf09 100644
--- a/oox/source/drawingml/chart/objectformatter.cxx
+++ b/oox/source/drawingml/chart/objectformatter.cxx
@@ -829,8 +829,8 @@ LineFormatter::LineFormatter( ObjectFormatterData& rData, const AutoFormatEntry*
if( const Theme* pTheme = mrData.mrFilter.getCurrentTheme() )
if( const LineProperties* pLineProps = pTheme->getLineStyle( pAutoFormatEntry->mnThemedIdx ) )
*mxAutoLine = *pLineProps;
- // set automatic border property for chartarea, because of tdf#81437 and tdf#82217
- if ( eObjType == OBJECTTYPE_CHARTSPACE )
+ // set automatic border property for chartarea, because of tdf#81437 and tdf#82217, except for pptx (tdf#150176)
+ if ( eObjType == OBJECTTYPE_CHARTSPACE && !rData.mrFilter.getFileUrl().endsWithIgnoreAsciiCase(".pptx") )
{
mxAutoLine->maLineFill.moFillType = oox::GraphicHelper::getDefaultChartAreaLineStyle();
mxAutoLine->moLineWidth = oox::GraphicHelper::getDefaultChartAreaLineWidth();